[ARVADOS-WORKBENCH2] updated: 2.1.0-262-gc37e5ca8

Git user git at public.arvados.org
Tue Mar 23 19:12:49 UTC 2021


Summary of changes:
 src/store/context-menu/context-menu-actions.test.ts | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

       via  c37e5ca83f9bf2dd7f3b1deca62b4ee1614dff99 (commit)
      from  21abfcbaba4e8e735f353a1e3b030dd5dae8465b (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.


commit c37e5ca83f9bf2dd7f3b1deca62b4ee1614dff99
Author: Ward Vandewege <ward at curii.com>
Date:   Tue Mar 23 15:11:22 2021 -0400

    17119: rename a field in the context menu actions unit test, for
           clarity.
    
    Arvados-DCO-1.1-Signed-off-by: Ward Vandewege <ward at curii.com>

diff --git a/src/store/context-menu/context-menu-actions.test.ts b/src/store/context-menu/context-menu-actions.test.ts
index 179e3a3c..36976336 100644
--- a/src/store/context-menu/context-menu-actions.test.ts
+++ b/src/store/context-menu/context-menu-actions.test.ts
@@ -24,7 +24,7 @@ describe('context-menu-actions', () => {
 
         it('should return the correct menu kind', () => {
             const cases = [
                 // resourceUuid, isAdminUser, isEditable, isTrashed, readonly, expected
                 [headCollectionUuid, false, true, true, false, ContextMenuKind.TRASHED_COLLECTION],
                 [headCollectionUuid, false, true, false, false, ContextMenuKind.COLLECTION],
                 [headCollectionUuid, false, true, false, true, ContextMenuKind.READONLY_COLLECTION],
@@ -87,7 +87,7 @@ describe('context-menu-actions', () => {
                 [containerRequestUuid, true, false, false, true, ContextMenuKind.READONLY_PROCESS_RESOURCE],
             ]
 
-            cases.forEach(([resourceUuid, isAdminUser, isEditable, isTrashed, readonly, expected]) => {
+            cases.forEach(([resourceUuid, isAdminUser, isEditable, isTrashed, forceReadonly, expected]) => {
                 const initialState = {
                     properties: {
                         [PROJECT_PANEL_CURRENT_UUID]: projectUuid,
@@ -138,10 +138,10 @@ describe('context-menu-actions', () => {
 
                 let menuKind: any;
                 try {
-                    menuKind = store.dispatch<any>(resourceUuidToContextMenuKind(resourceUuid as string, readonly as boolean))
+                    menuKind = store.dispatch<any>(resourceUuidToContextMenuKind(resourceUuid as string, forceReadonly as boolean))
                     expect(menuKind).toBe(expected);
                 } catch (err) {
-                    throw new Error(`menuKind for resource ${JSON.stringify(initialState.resources[resourceUuid as string])} readonly: ${readonly} expected to be ${expected} but got ${menuKind}.`);
+                    throw new Error(`menuKind for resource ${JSON.stringify(initialState.resources[resourceUuid as string])} forceReadonly: ${forceReadonly} expected to be ${expected} but got ${menuKind}.`);
                 }
             });
         });

-----------------------------------------------------------------------
@@ -24,7 +24,7 @@ describe('context-menu-actions', () => {
         it('should return the correct menu kind', () => {
             const cases = [
-                // resourceUuid, isAdminUser, isEditable, isTrashed, readonly, expected
+                // resourceUuid, isAdminUser, isEditable, isTrashed, forceReadonly, expected
                 [headCollectionUuid, false, true, true, false, ContextMenuKind.TRASHED_COLLECTION],
                 [headCollectionUuid, false, true, false, false, ContextMenuKind.COLLECTION],


hooks/post-receive
-- 




More information about the arvados-commits mailing list